@@ -18,7 +18,7 @@ __all__ = (
 )
 
 
-class FittedPowerLaw(object):
+class FittedPowerLaw:
     """Result of fitting a power-law to a vector of samples
 
     Example:
@@ -104,7 +104,7 @@ D=0.21..., p=0.993...)
         return "\n".join(result)
 
 
-class Histogram(object):
+class Histogram:
     """Generic histogram class for real numbers
 
     Example:
@@ -230,39 +230,12 @@ class Histogram(object):
             yield (x, x + self._bin_width, elem)
             x += self._bin_width
 
-    def __plot__(self, context, bbox, _, **kwds):
+    def __plot__(self, backend, context, **kwds):
         """Plotting support"""
-        from igraph.drawing.coord import DescartesCoordinateSystem
+        from igraph.drawing import DrawerDirectory
 
-        coord_system = DescartesCoordinateSystem(
-            context,
-            bbox,
-            (
-                kwds.get("min", self._min),
-                0,
-                kwds.get("max", self._max),
-                kwds.get("max_value", max(self._bins)),
-            ),
-        )
-
-        # Draw the boxes
-        context.set_line_width(1)
-        context.set_source_rgb(1.0, 0.0, 0.0)
-        x = self._min
-        for value in self._bins:
-            top_left_x, top_left_y = coord_system.local_to_context(x, value)
-            x += self._bin_width
-            bottom_right_x, bottom_right_y = coord_system.local_to_context(x, 0)
-            context.rectangle(
-                top_left_x,
-                top_left_y,
-                bottom_right_x - top_left_x,
-                bottom_right_y - top_left_y,
-            )
-            context.fill()
-
-        # Draw the axes
-        coord_system.draw()
+        drawer = DrawerDirectory.resolve(self, backend)(context)
+        drawer.draw(self, **kwds)
 
     def to_string(self, max_width=78, show_bars=True, show_counts=True):
         """Returns the string representation of the histogram.
@@ -324,7 +297,7 @@ class Histogram(object):
         return self.to_string()
 
 
-class RunningMean(object):
+class RunningMean:
     """Running mean calculator.
 
     This class can be used to calculate the mean of elements from a
@@ -432,7 +405,7 @@ class RunningMean(object):
     @property
     def var(self):
         """Returns the current variation"""
-        return self._sd ** 2
+        return self._sd**2
 
     def __repr__(self):
         return "%s(n=%r, mean=%r, sd=%r)" % (
@@ -529,9 +502,16 @@ def percentile(xs, p=(25, 50, 75), sort=True):
     return quantile(xs, p / 100.0, sort)
 
 
-def power_law_fit(data, xmin=None, method="auto", return_alpha_only=False):
+def power_law_fit(data, xmin=None, method="auto", p_precision=0.01):
     """Fitting a power-law distribution to empirical data
 
+    B{References}
+
+      - MEJ Newman: Power laws, Pareto distributions and Zipf's law.
+        I{Contemporary Physics} 46, 323-351 (2005)
+      - A Clauset, CR Shalizi, MEJ Newman: Power-law distributions
+        in empirical data. E-print (2007). arXiv:0706.1062
+
     @param data: the data to fit, a list containing integer values
     @param xmin: the lower bound for fitting the power-law. If C{None},
       the optimal xmin value will be estimated as well. Zero means that
@@ -557,16 +537,16 @@ def power_law_fit(data, xmin=None, method="auto", return_alpha_only=False):
           method is used if the input vector contains at least one fractional
           value and the discrete method is used if the input vector contains
           integers only.
+    @param p_precision: desired precision of the p-value calculation. The
+      precision ultimately depends on the number of resampling attempts. The
+      number of resampling trials is determined by 0.25 divided by the square
+      of the required precision. For instance, a required precision of 0.01
+      means that 2500 samples will be drawn.
 
     @return: a L{FittedPowerLaw} object. The fitted C{xmin} value and the
       power-law exponent can be queried from the C{xmin} and C{alpha}
       properties of the returned object.
-
-    @newfield ref: Reference
-    @ref: MEJ Newman: Power laws, Pareto distributions and Zipf's law.
-      Contemporary Physics 46, 323-351 (2005)
-    @ref: A Clauset, CR Shalizi, MEJ Newman: Power-law distributions
-      in empirical data. E-print (2007). arXiv:0706.1062"""
+    """
     from igraph._igraph import _power_law_fit
 
     if xmin is None or xmin < 0:
@@ -577,17 +557,7 @@ def power_law_fit(data, xmin=None, method="auto", return_alpha_only=False):
         raise ValueError("unknown method: %s" % method)
 
     force_continuous = method in ("continuous", "hill")
-    fit = FittedPowerLaw(*_power_law_fit(data, xmin, force_continuous))
-    if return_alpha_only:
-        from igraph import deprecated
-
-        deprecated(
-            "The return_alpha_only keyword argument of power_law_fit is "
-            "deprecated from igraph 0.7 and will be removed in igraph 0.8"
-        )
-        return fit.alpha
-    else:
-        return fit
+    return FittedPowerLaw(*_power_law_fit(data, xmin, force_continuous, p_precision))
 
 
 def quantile(xs, q=(0.25, 0.5, 0.75), sort=True):
